Introduction
============

.. image:: https://badge.fury.io/py/rbottle.png
    :target: http://badge.fury.io/py/rbottle

.. image:: https://pypip.in/d/rbottle/badge.png
        :target: https://crate.io/packages/rbottle?version=latest

This package is used to make easier creating REST applications using
`Bottle <http://bottlepy.org>`_ web framework.

Documentation
-------------

Full module documentation and description can be found at Read the Docs:

- http://rbottle.readthedocs.org/